SystemOrganization addCategory: #ConfigurationOfControl!

Object subclass: #ConfigurationOfControl
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfControl'!

!ConfigurationOfControl class methodsFor: 'development support' stamp: 'fbs 3/6/2012 10:46'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfControl class methodsFor: 'private' stamp: 'fbs 3/6/2012 10:46'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].! !

!ConfigurationOfControl class methodsFor: 'private' stamp: 'fbs 3/6/2012 10:46'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfControl class methodsFor: 'development support' stamp: 'fbs 3/6/2012 10:46'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfControl class methodsFor: 'development support' stamp: 'fbs 3/6/2012 10:46'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfControl class methodsFor: 'private' stamp: 'fbs 3/6/2012 10:46'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."
	| meta |
	meta := 'ConfigurationOfMetacello-dkh.674'.
	Smalltalk at: #MetacelloProject ifAbsent: [
		"list of repositories to try, in case primary repository is not accessible"
		self bootstrapPackage: meta from: 'http://www.squeaksource.com/MetacelloRepository'.
		Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
		Smalltalk at: #MetacelloProject ifAbsent: [
			self bootstrapPackage: meta from: 'http://seaside.gemstone.com/ss/metacello'.
			Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
			Smalltalk at: #MetacelloProject ifAbsent: [self error: 'Couldn''t load Metacello']]].! !

!ConfigurationOfControl class methodsFor: 'private' stamp: 'fbs 3/6/2012 10:46'!
ensureMetacelloBaseConfiguration
	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self bootstrapPackage: 'Metacello-Base-DaleHenrichs.19' from: 'http://seaside.gemstone.com/ss/metacello']! !

!ConfigurationOfControl class methodsFor: 'metacello tool support' stamp: 'fbs 3/6/2012 10:46'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfControl class methodsFor: 'metacello tool support' stamp: 'fbs 3/6/2012 10:46'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfControl class methodsFor: 'loading' stamp: 'fbs 3/6/2012 10:46'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfControl class methodsFor: 'loading' stamp: 'fbs 3/6/2012 10:46'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfControl class methodsFor: 'loading' stamp: 'fbs 3/6/2012 10:46'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfControl class methodsFor: 'loading' stamp: 'fbs 3/6/2012 10:46'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfControl class methodsFor: 'metacello tool support' stamp: 'fbs 3/6/2012 10:46'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfControl class methodsFor: 'accessing' stamp: 'fbs 3/6/2012 10:46'!
project
	^self new project! !

!ConfigurationOfControl class methodsFor: 'unloading metacello' stamp: 'fbs 3/6/2012 10:46'!
unloadMetacello
	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfControl class methodsFor: 'development support' stamp: 'fbs 3/6/2012 10:46'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- latest mcz files for 1.0.4'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfControl class methodsFor: 'development support' stamp: 'fbs 3/6/2012 10:46'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfControl methodsFor: 'baselines' stamp: 'fbs 8/29/2012 22:07'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Control'.
		spec 
			package: 'Control';
			package: 'ControlTests' with: [
				spec requires: #('Control' )].
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Control');
			group: 'Tests' with: #('ControlTests') ].
	spec for: #'squeak' do: [ ].
	spec for: #'pharo' do: [
		spec
			package: 'ControlPharo'].! !

!ConfigurationOfControl methodsFor: 'symbolic versions' stamp: 'fbs 3/6/2012 10:49'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.1.dev'! !

!ConfigurationOfControl methodsFor: 'accessing' stamp: 'fbs 3/6/2012 10:46'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		"Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
			versionString := cl current version.
			((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
				ifTrue: [ projectAttributes := projectAttributes, #() ] ]."
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfControl methodsFor: 'symbolic versions' stamp: 'fbs 3/6/2012 10:48'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'! !

!ConfigurationOfControl methodsFor: 'versions' stamp: 'fbs 3/6/2012 10:48'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'stable version'.
		spec author: 'fbs'.
		spec timestamp: '06/03/2011 10:47'.
		spec
			package: 'Control' with: 'Control-fbs.11';
			package: 'ControlTests' with: 'ControlTests-fbs.8'. ].
		spec for: #squeak do: [ ].
		spec for: #pharo do: [ ].
! !

!ConfigurationOfControl methodsFor: 'versions' stamp: 'fbs 8/29/2012 21:33'!
version11dev: spec
	<version: '1.1.dev' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'stable version'.
		spec author: 'fbs'.
		spec timestamp: '07/14/2012 21:37'.
		spec
			package: 'Control' with: 'Control-fbs.19';
			package: 'ControlTests' with: 'ControlTests-fbs.15'. ].
		spec for: #squeak do: [ ].
		spec for: #pharo do: [
			spec
				package: 'ControlPharo' with: 'ControlPharo-fbs.1' ].
! !
